@@ -1356,6 +1356,7 @@ void ScheduleGUI_BackupDataPoints()
 {
  //first free any previous backup:
  ScheduleGUI_CleanupDataPoints(ScheduleGUI_FirstBackupDataPoint);
+ ScheduleGUI_FirstBackupDataPoint=NULL;//Added 20060501 
   
  //allot memory for first backup data point, so there is a valid starting point for linked list:
  ScheduleGUI_FirstBackupDataPoint=(DataPoint *)malloc(sizeof(DataPoint));
@@ -1619,6 +1620,7 @@ gtk_widget_queue_draw_area (widget,0,0,widget->allocation.width, widget->allocat
 /////////////////////////////////////////////////////
 //20060326: this was made to be able to clean any linked list of
 //data points (so both main and backup sets can use this func)
+//NOTE: User must now make sure to NULL their own FirstDataPoint when done!
 void ScheduleGUI_CleanupDataPoints(DataPoint * firstDataPoint)
 {
  if (firstDataPoint==NULL) return;
@@ -1643,8 +1645,8 @@ void ScheduleGUI_CleanupDataPoints(DataPoint * firstDataPoint)
   if (firstDataPoint==ScheduleGUI_FirstDataPoint)  { DBGOUT("DataPoints Deleted:",count) }
   else { DBGOUT("Undo DataPoints Deleted:",count) }
 		  
-  //Make sure this First Data Point is NULLED!:
-  firstDataPoint=NULL;
+  //User must make sure to NULL their First Data Point!
+//  firstDataPoint=NULL;
 }
 
 
@@ -1918,7 +1920,7 @@ void ScheduleGUI_SetupDataPoints()
 //#################	
 //this is the line that connects data up to current BinauralBeat data: 
 	ScheduleGUI_CleanupDataPoints(ScheduleGUI_FirstDataPoint); 
- ScheduleGUI_FirstDataPoint=NULL; //can't say this enough!
+ ScheduleGUI_FirstDataPoint=NULL; //Must do this after calling ScheduleGUI_CleanupDataPoints!
  for (int i=0; i<bb->ScheduleEntriesCount; i++)
  {
   ScheduleGUI_AddNewDataPointToEnd(bb->Schedule[i].Duration, 
@@ -2034,7 +2036,9 @@ void ScheduleGUI_Cleanup()
  ScheduleGUI_gc=NULL;
  ScheduleGUI_layout=NULL;
  ScheduleGUI_CleanupDataPoints(ScheduleGUI_FirstBackupDataPoint);
+ ScheduleGUI_FirstBackupDataPoint=NULL;//ALWAYS REMEMBER TO DO THIS!
 	ScheduleGUI_CleanupDataPoints(ScheduleGUI_FirstDataPoint);
+ ScheduleGUI_FirstDataPoint=NULL;//ALWAYS REMEMBER TO DO THIS!
 	if (ScheduleGUI_CopyPaste.data != NULL) free(ScheduleGUI_CopyPaste.data);
 }
 
